@@ -22,11 +22,6 @@ use Data::Dumper;
 #$Data::Dumper::Terse  = 1;
 use Data::Dump qw(dump);
 use feature 'say';
-#use feature qw(postderef);
-#no warnings qw(experimental::postderef);
-#use Sub::Signatures;
-#no warnings qw(Sub::Signatures); 
-#no strict 'refs';
 use Sim::OPT;
 use Sim::OPT::Morph;
 use Sim::OPT::Sim;
@@ -77,7 +72,6 @@ sub descend
 	$toshell = $main::toshell;
 	$report = $main::report;
 	$simnetwork = $main::simnetwork;
-	$reportloadsdata = $main::reportloadsdata;
 	
 	open ( OUTFILE, ">>$outfile" ) or die "Can't open $outfile: $!"; 
 	open ( TOSHELL, ">>$toshell" ) or die "Can't open $toshell: $!";  
@@ -104,7 +98,7 @@ sub descend
 	@reporttempsdata = @main::reporttempsdata;
 	@reportcomfortdata = @main::reportcomfortdata;
 	@reportradiationenteringdata = @main::reportradiationenteringdata;
-	@reporttempsstats = @main::reporttempsstats;
+	@report_loadsortemps = @main::report_loadsortemps;
 	@files_to_filter = @main::files_to_filter;
 	@filter_reports = @main::filter_reports;
 	@base_columns = @main::base_columns;
