@@ -28,11 +28,6 @@ use Data::Dumper;
 #$Data::Dumper::Terse  = 1;
 use Data::Dump qw(dump);
 use feature 'say';
-#use feature qw(postderef);
-#no warnings qw(experimental::postderef);
-#use Sub::Signatures;
-#no warnings qw(Sub::Signatures); 
-#no strict 'refs';
 no strict; 
 no warnings;
 
@@ -77,7 +72,6 @@ sub retrieve
 	$toshell = $main::toshell;
 	$report = $main::report;
 	$simnetwork = $main::simnetwork;
-	$reportloadsdata = $main::reportloadsdata;
 	
 	$tee = new IO::Tee(\*STDOUT, ">>$toshell"); # GLOBAL ZZZ
 	
@@ -104,7 +98,7 @@ sub retrieve
 	@reporttempsdata = @main::reporttempsdata;
 	@reportcomfortdata = @main::reportcomfortdata;
 	@reportradiationenteringdata = @main::reportradiationenteringdata;
-	@reporttempsstats = @main::reporttempsstats;
+	@report_loadsortemps = @main::report_loadsortemps;
 	@files_to_filter = @main::files_to_filter;
 	@filter_reports = @main::filter_reports;
 	@base_columns = @main::base_columns;
@@ -188,15 +182,10 @@ sub retrieve
 
 		sub retrieve_temperatures_results 
 		{
-			my $result = shift;
-			my $resfile = shift;
-			my $swap = shift;
+			my ( $result, $resfile, $swap, $reporttitle, $theme, $counttheme, $countreport, $retfile ) = @_;
+			
 			my @retrdata = @$swap;
-			my $reporttitle = shift;
-			my $theme = shift;
-			my $counttheme = shift;
-			my $countreport = shift;
-			my $retfile = shift;
+			
 			#my $existingfile = "$resfile-$theme.grt";
 			#if (-e $existingfile) { print `chmod 777 $existingfile\n`;} 
 			#print $_toshell_ "chmod 777 $existingfile\n";
@@ -264,16 +253,10 @@ YYY
 
 		sub retrieve_comfort_results
 		{
-			my $result = shift;
-			my $resfile = shift;
-			my $swap = shift;
+			my ( $result, $resfile, $swap, $reporttitle, $stripcheck, $theme, $counttheme, $countreport, $retfile ) = @_;
+			
 			my @retrdata = @$swap;
-			my $reporttitle = shift;
-			my $stripcheck = shift;
-			my $theme = shift;
-			my $counttheme = shift;
-			my $countreport = shift;
-			my $retfile = shift;
+			
 			#my $existingfile = "$resfile-$theme.grt"; 
 			#if (-e $existingfile) { print `chmod 777 $existingfile\n`;} 
 			#print $_toshell_ "chmod 777 $existingfile\n";
@@ -330,15 +313,11 @@ ZZZ
 
 			sub retrieve_loads_results
 			{	
-				my $result = shift; #say TOSHELL "\$result: " . dump($result);
-				my $resfile = shift; #say TOSHELL "\$resfile " . dump($resfile);
-				my $swap = shift; 
+				my ( $result, $resfile, $swap, $reporttitle, $theme, $counttheme, $countreport, $retfile ) = @_;
+				print TOSHELL " IN RETRIEVE LOADS: \$sim: $sim, \$resfile: $resfile, \$result: $result, \@retrievedata: @retrievedata, \$reporttitle: $reporttitle, \$theme: $theme, \$counttheme: $counttheme, \$countreport, $countreport, \$retfile : $retfile \n";
+								
 				my @retrdata = @$swap; #say TOSHELL "\@retrdata " . dump(@retrdata);
-				my $reporttitle = shift; #say TOSHELL "\$reporttitle " . dump($reporttitle);
-				my $theme = shift; #say TOSHELL "\$theme " . dump($theme);
-				my $counttheme = shift;
-				my $countreport = shift;
-				my $retfile = shift;
+				
 				#my $existingfile = "$resfile-$theme.grt";
 				#if (-e $existingfile) { print `chmod 777 $existingfile\n`;}
 				#print $_toshell_ "chmod 777 $existingfile\n";
@@ -359,8 +338,7 @@ d
 a
 $retfile
 $retfile
-a
-h
+l
 a
 -
 -
@@ -402,15 +380,11 @@ $printthis
 			sub retrieve_temps_stats
 			{
 				say TOSHELL "\nNow in Sim::OPT::Retrieve. IN TEMPSSTATS";
-				my $result = shift; say "$result: " . dump($result); 
-				my $resfile = shift; say "$resfile " . dump($resfile); 
-				my $swap = shift; say "$swap " . dump($swap); 
+				my ( $result, $resfile, $swap, $reporttitle, $theme, $counttheme, $countreport, $retfile ) = @_; 
+				print TOSHELL "IN RETRIEVE TEMPSSTATS: \$sim: $sim, \$resfile: $resfile, \$result: $result, \@retrievedata: @retrievedata, \$reporttitle: $reporttitle, \$theme: $theme, \$counttheme: $counttheme, \$countreport, $countreport, \$retfile : $retfile \n";
+				
 				my @retrdata = @$swap; say "@retrdata " . dump(@retrdata); 
-				my $reporttitle = shift; say "$reporttitle " . dump($reporttitle); 
-				my $theme = shift; say "$theme " . dump($theme); 
-				my $counttheme = shift; say "$counttheme " . dump($counttheme); 
-				my $countreport = shift; say "$countreport " . dump($countreport); 
-				my $retfile = shift; say "$retfile " . dump($retfile); 
+				
 				#my $existingfile = "$resfile-$theme.grt";
 				#if (-e $existingfile) { print `chmod 777 $existingfile\n`; }
 				#print $_toshell_ "chmod 777 $existingfile\n";
@@ -433,9 +407,7 @@ d
 a
 $retfile
 $retfile
-a
-b
-e
+m
 -
 -
 -
@@ -479,40 +451,38 @@ $printthis";
 			}
 		}
 		
-		
-		say TOSHELL "\nNow in Sim::OPT::Retrieve. INSIDE";
+		#say TOSHELL "\nNow in Sim::OPT::Retrieve. INSIDE";
 		my $resfile = $simstruct[$countcase][$countblock][$countinstance]; #$simcases[$countinstance]; ### HERE!!! ZZZ 
-		say TOSHELL "SAY\@simcases " . dump(@simcases); say TOSHELL "SAY\@simstruct " . dump(@simstruct); 
+		#say TOSHELL "SAY\@simcases " . dump(@simcases); say TOSHELL "SAY\@simstruct " . dump(@simstruct); 
 		
 		my $counttheme = 0;
 		foreach my $retrievedatum (@retrievedata)
 		{
-			say TOSHELL "\nNow in Sim::OPT::Retrieve. IN THEMES";
-			
-			say TOSHELL "dumpINRETRIEVE(\@themereports): " . dump(@themereports);
-			say TOSHELL "dumpINRETRIEVE(\@simtitles): " . dump(@simtitles);
-			say TOSHELL "dump(\$dat{morphlist}): " . dump($dat{morphlist});
-			say TOSHELL "dump(\$simlist): " . dump($simlist);
+			#say TOSHELL "\nNow in Sim::OPT::Retrieve. IN THEMES";
+			#say TOSHELL "dumpINRETRIEVE(\@themereports): " . dump(@themereports);
+			#say TOSHELL "dumpINRETRIEVE(\@simtitles): " . dump(@simtitles);
+			#say TOSHELL "dump(\$dat{morphlist}): " . dump($dat{morphlist});
+			#say TOSHELL "dump(\$simlist): " . dump($simlist);
 
-			my @themereports = @{$themereports[$counttheme]}; say TOSHELL "\@themereports " . dump(@themereports);
+			my @themereports = @{$themereports[$counttheme]}; #say TOSHELL "\@themereports " . dump(@themereports);
 			my $reporttitlesref = $reporttitles[$counttheme];
-			my @reporttitles = @{$reporttitlesref}; say TOSHELL "\@reporttitles " . dump(@reporttitles);
+			my @reporttitles = @{$reporttitlesref}; #say TOSHELL "\@reporttitles " . dump(@reporttitles);
 			my $retrievedatarefsdeep = $retrievedata[$counttheme];
 			my @retrievedatarefs = @{$retrievedatum};
-			my $simtitle = $simtitles[$counttheme]; say TOSHELL "\$simtitle " . dump($simtitle);
-			my @sims = @{$simdata[$countheme]}; say TOSHELL "\@sims " . dump(@sims);
+			my $simtitle = $simtitles[$counttheme]; #say TOSHELL "\$simtitle " . dump($simtitle);
+			my @sims = @{$simdata[$countheme]}; #say TOSHELL "\@sims " . dump(@sims);
 			
 			my $countreport = 0;
 			foreach my $retrievedataref (@retrievedatarefs)
 			{
-				say TOSHELL "\nNow in Sim::OPT::Retrieve. IN RESULTS";
-				my $theme = $themereports[$countreport]; say TOSHELL "\$theme: " . dump($theme);
-				my $reporttitle = $reporttitles[$countreport]; say TOSHELL "\$reporttitle " . dump($reporttitle);
-				my @retrdata = @$retrievedataref; say TOSHELL "\@retrdata " . dump(@retrdata);
-				my $sim = $sims[$countreport]; say TOSHELL "\$sim-RESFILE" . dump($sim); 
+				#say TOSHELL "\nNow in Sim::OPT::Retrieve. IN RESULTS";
+				my $theme = $themereports[$countreport]; #say TOSHELL "\$theme: " . dump($theme);
+				my $reporttitle = $reporttitles[$countreport]; #say TOSHELL "\$reporttitle " . dump($reporttitle);
+				my @retrdata = @$retrievedataref; #say TOSHELL "\@retrdata " . dump(@retrdata);
+				my $sim = $sims[$countreport]; #say TOSHELL "\$sim-RESFILE" . dump($sim); 
 				my $targetprov = $sim;
 				$targetprov =~ s/$mypath\///;
-				my $result = "$mypath" . "/$targetprov"; say TOSHELL "\$result " . dump($result); 
+				my $result = "$mypath" . "/$targetprov"; #say TOSHELL "\$result " . dump($result); 
 				
 				#if ( fileno (RETLIST) )
 				#if (not (-e $retlist ) )
@@ -556,7 +526,7 @@ $printthis";
 					if ( $theme eq "comfort"  ) { &retrieve_comfort_results($result, $resfile, \@retrdata, $reporttitle, $theme, $counttheme, $countreport, $retfile ); }
 					if ( $theme eq "loads" ) 	{ &retrieve_loads_results($result, $resfile, \@retrdata, $reporttitle, $theme, $counttheme, $countreport, $retfile ); }
 					if ( $theme eq "tempsstats"  ) { &retrieve_temps_stats($result, $resfile, \@retrdata, $reporttitle, $theme, $counttheme, $countreport, $retfile ); }
-					print OUTFILE "\$sim: $sim, \$resfile: $resfile, \$result: $result, \@retrievedata: @retrievedata, \$reporttitle: $reporttitle, \$theme: $theme, \$counttheme: $counttheme, \$countreport, $countreport, \$retfile : $retfile \n";
+					#print TOSHELL "\$sim: $sim, \$resfile: $resfile, \$result: $result, \@retrievedata: @retrievedata, \$reporttitle: $reporttitle, \$theme: $theme, \$counttheme: $counttheme, \$countreport, $countreport, \$retfile : $retfile \n";
 				
 				$countreport++;
 			}
@@ -573,11 +543,6 @@ $printthis";
 	return (\@retcases, \@retstruct);
 }	# END SUB RETRIEVE
 
-##############################################################################
-##############################################################################
-##############################################################################
-# END SUB RETRIEVE
-
 sub report { ; } # NO MORE USED # This function retrieved the results of interest from the text file created by the "retrieve" function
 
 1;
