@@ -83,7 +83,6 @@ sub sim    # This function launch the simulations in ESP-r
 	$toshell = $main::toshell;
 	$report = $main::report;
 	$simnetwork = $main::simnetwork;
-	$reportloadsdata = $main::reportloadsdata;
 	
 	$tee = new IO::Tee(\*STDOUT, ">>$toshell"); # GLOBAL ZZZ
 	
@@ -110,7 +109,7 @@ sub sim    # This function launch the simulations in ESP-r
 	@reporttempsdata = @main::reporttempsdata;
 	@reportcomfortdata = @main::reportcomfortdata;
 	@reportradiationenteringdata = @main::reportradiationenteringdata;
-	@reporttempsstats = @main::reporttempsstats;
+	@report_loadsortemps = @main::report_loadsortemps;
 	@files_to_filter = @main::files_to_filter;
 	@filter_reports = @main::filter_reports;
 	@base_columns = @main::base_columns;
